Package: limpca
Type: Package
Title: An R package for the linear modeling of high-dimensional
        designed data based on ASCA/APCA family of methods
Version: 1.8.0
Authors@R: c(person("Bernadette", "Govaerts", role = c("aut", "ths"),
                     email = "bernadette.govaerts@uclouvain.be"),
              person("Sebastien","Franceschini", role = "ctb",
                    email="sfranceschini@uliege.be"),
              person("Robin","van Oirbeek", role = "ctb",
                    email="robin.vanoirbeek@gmail.com"),
              person("Michel","Thiel", role = "aut",
                    email="michel.thiel@uclouvain.be"),
              person("Pascal","de Tullio", role = "dtc",
                    email="pdetullio@uliege.be"),
              person("Manon","Martin", role = c("aut", "cre"),
                    email="manon.martin@uclouvain.be",
                    comment = c(ORCID = "0000-0003-4800-0942")),
              person("Nadia", "Benaiche", role = "ctb",
                     email = "nadia.benaiche@student.uclouvain.be"))
Description: This package has for objectives to provide a method to
        make Linear Models for high-dimensional designed data. limpca
        applies a GLM (General Linear Model) version of ASCA and APCA
        to analyse multivariate sample profiles generated by an
        experimental design. ASCA/APCA provide powerful visualization
        tools for multivariate structures in the space of each effect
        of the statistical model linked to the experimental design and
        contrarily to MANOVA, it can deal with mutlivariate datasets
        having more variables than observations. This method can handle
        unbalanced design.
License: Artistic-2.0
Encoding: UTF-8
LazyData: FALSE
VignetteBuilder: knitr
Imports: ggplot2, stringr, plyr, ggrepel, reshape2, grDevices,
        graphics, doParallel, parallel, dplyr, tibble, tidyr, ggsci,
        tidyverse, methods, stats, SummarizedExperiment, S4Vectors
Suggests: BiocStyle, pander, rmarkdown, car, gridExtra, knitr, testthat
        (>= 3.0.0)
biocViews: StatisticalMethod, PrincipalComponent, Regression,
        Visualization, ExperimentalDesign, MultipleComparison,
        GeneExpression, Metabolomics
RoxygenNote: 7.3.3
Roxygen: list(markdown=TRUE)
BugReports: https://github.com/ManonMartin/limpca/issues
URL: https://github.com/ManonMartin/limpca,
        https://manonmartin.github.io/limpca/
Config/testthat/edition: 3
Config/pak/sysreqs: cmake libfontconfig1-dev libfreetype6-dev
        libfribidi-dev make libharfbuzz-dev libicu-dev libjpeg-dev
        libpng-dev libtiff-dev libuv1-dev libwebp-dev libxml2-dev
        libssl-dev libx11-dev zlib1g-dev
Repository: https://bioc-release.r-universe.dev
Date/Publication: 2026-04-28 13:03:08 UTC
RemoteUrl: https://github.com/bioc/limpca
RemoteRef: RELEASE_3_23
RemoteSha: 6ef673cca64c39757e06f412054fa883e70cac52
NeedsCompilation: no
Packaged: 2026-04-29 23:10:22 UTC; root
Author: Bernadette Govaerts [aut, ths],
  Sebastien Franceschini [ctb],
  Robin van Oirbeek [ctb],
  Michel Thiel [aut],
  Pascal de Tullio [dtc],
  Manon Martin [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-4800-0942>),
  Nadia Benaiche [ctb]
Maintainer: Manon Martin <manon.martin@uclouvain.be>
Depends: R (>= 3.5.0)
Built: R 4.6.0; ; 2026-04-30 00:21:03 UTC; unix
