# Generated by roxygen2: do not edit by hand

export(data2LmpDataList)
export(lmpBootstrapTests)
export(lmpContributions)
export(lmpEffectMatrices)
export(lmpEffectPlot)
export(lmpLoading1dPlot)
export(lmpLoading2dPlot)
export(lmpModelMatrix)
export(lmpPcaEffects)
export(lmpScorePlot)
export(lmpScoreScatterPlotM)
export(lmpScreePlot)
export(pcaBySvd)
export(pcaLoading1dPlot)
export(pcaLoading2dPlot)
export(pcaScorePlot)
export(pcaScreePlot)
export(plotDesign)
export(plotLine)
export(plotMeans)
export(plotScatter)
export(plotScatterM)
import(SummarizedExperiment)
import(doParallel)
import(dplyr)
import(ggplot2)
import(ggrepel)
import(ggsci)
import(grDevices)
import(graphics)
import(parallel)
import(reshape2)
import(stringr)
import(tibble)
import(tidyr)
import(tidyverse)
importFrom(S4Vectors,metadata)
importFrom(methods,hasArg)
importFrom(methods,is)
importFrom(plyr,aaply)
importFrom(plyr,ddply)
importFrom(plyr,is.formula)
importFrom(plyr,laply)
importFrom(plyr,llply)
importFrom(stats,aggregate)
importFrom(stats,as.formula)
importFrom(stats,model.matrix)
